
<div class="slidecontainer">
  <input type="range" min="{{min_date}}" max="{{max_date}}" value="{{max_date}}" class="slider" id="myRange">
  <div class="slidertext">Year: <span id="demo"></span></div>
</div>